@@ -1,6 +1,6 @@
 import attr
 
-from .base import __compiler__, Element
+from .base import Element, __compiler__
 
 __t__ = __compiler__.compile("{{#if value}}true{{else}}false{{/if}}")
 
