@@ -1,7 +1,8 @@
-import attr
 from typing import Optional
 
-from .base import __compiler__, Element, render
+import attr
+
+from .base import Element, __compiler__, render
 
 __t__ = __compiler__.compile(
     """output "{{{name}}}" {
