@@ -1,7 +1,16 @@
-import attr
 from typing import Union
 
-from .base import __compiler__, Element, is_literal, is_heredoc, strip_literal, quote, clear_literal
+import attr
+
+from .base import (
+    Element,
+    __compiler__,
+    clear_literal,
+    is_heredoc,
+    is_literal,
+    quote,
+    strip_literal,
+)
 
 __t__ = __compiler__.compile("{{{value}}}")
 
