@@ -1,5 +1,5 @@
 import os
-from typing import List, TYPE_CHECKING
+from typing import TYPE_CHECKING, List
 
 if TYPE_CHECKING:
     from terrascript.core.lang.block import Block
