@@ -1,5 +1,6 @@
+from typing import Any, Optional
+
 import attr as attrs
-from typing import Optional, Any
 
 from .attribute import Kind
 
