@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import inspect
-import attr as attrs
 from abc import ABC, abstractmethod
 from typing import (
     Any,
@@ -11,23 +10,25 @@ from typing import (
     Optional,
     TypeVar,
     Union,
+    cast,
     get_args,
     get_origin,
-    cast,
 )
 
-from pydash import (
-    is_boolean,
-    is_empty,
-    is_float,
-    is_integer,
-    is_string,
-    trim_end,
-)
+import attr as attrs
+from pydash import is_boolean, is_empty, is_float, is_integer, is_string, trim_end
 
+from ..ast import (
+    AstArgument,
+    AstArray,
+    AstBoolean,
+    AstMap,
+    AstNumber,
+    AstString,
+    Element,
+)
 from .argument import Argument
 from .attribute import Attribute
-from ..ast import AstArgument, AstArray, AstBoolean, AstMap, AstNumber, AstString, Element
 
 
 def is_optional(typ: Optional[type]) -> bool:
@@ -286,7 +287,7 @@ def parse_schema(value: Schema) -> List[Element]:
         elif is_schema_map(v):
             items = parse_map(v)
             if not is_empty(items):
-                elements.append(AstArgument(field.name, op="", value=items))
+                elements.append(AstArgument(field.name, value=items))
 
         elif is_schema(v):
             items = parse_schema(v)
