@@ -1,8 +1,7 @@
 from typing import Optional
 
-from ...lang.decorators import schema, schema_args
+from ...lang.decorators import arg, schema, schema_args
 from ...lang.types import Schema, SchemaArgs
-from ...lang.decorators import arg
 
 
 @schema
