@@ -1,9 +1,8 @@
 from typing import Optional
 
-from ..lang.decorators import schema, schema_args
+from ..lang.decorators import arg, schema, schema_args
 from ..lang.provider import Provider as Base
 from ..lang.types import SchemaArgs
-from ..lang.decorators import arg
 
 
 @schema
